pub struct File {
pub inner_pragmas: Vec<Pragma>,
pub span: Span,
pub nodes: Vec<Node>,
}Fields
inner_pragmas: Vec<Pragma>span: Spannodes: Vec<Node>Trait Implementations
Sourceimpl Parse for File
impl Parse for File
Sourcefn partial_parse_with_ctx<I: IntoIterator<Item = Token>>(
partial: bool,
ctx: ParseCtx<'_>,
token_stream: I,
) -> Result<Self, ()>
fn partial_parse_with_ctx<I: IntoIterator<Item = Token>>( partial: bool, ctx: ParseCtx<'_>, token_stream: I, ) -> Result<Self, ()>
Parse an AST node with a shared parsing context. Errors are emitted into
ctx. Read moreSourcefn parse_with_ctx<I: IntoIterator<Item = Token>>(
ctx: ParseCtx<'_>,
token_stream: I,
) -> Result<Self, ()>
fn parse_with_ctx<I: IntoIterator<Item = Token>>( ctx: ParseCtx<'_>, token_stream: I, ) -> Result<Self, ()>
Parse an AST node with a shared parsing context. Errors are emitted into
ctx. Read moreSourcefn partial_parse_with_interner(
partial: bool,
source: &str,
span_base: u32,
interner: &mut Interner,
) -> Result<Self, Vec<Error>>
fn partial_parse_with_interner( partial: bool, source: &str, span_base: u32, interner: &mut Interner, ) -> Result<Self, Vec<Error>>
Convenience method for parsing source without a shared context. Errors are returned
in the
Err variant. Read moreSourcefn parse_with_interner(
source: &str,
span_base: u32,
interner: &mut Interner,
) -> Result<Self, Vec<Error>>
fn parse_with_interner( source: &str, span_base: u32, interner: &mut Interner, ) -> Result<Self, Vec<Error>>
Convenience method for parsing source without a shared context. Errors are returned
in the
Err variant. Read moreimpl Eq for File
impl StructuralPartialEq for File