pub struct Lit {
pub kind: LitKind,
pub span: Span,
}Fields
kind: LitKindspan: SpanTrait Implementations
Sourceimpl Parse for Lit
impl Parse for Lit
Sourcefn partial_parse_with_ctx<I: IntoIterator<Item = Token>>(
partial: bool,
ctx: ParseCtx<'_>,
token_stream: I,
) -> Result<Self, ()>
fn partial_parse_with_ctx<I: IntoIterator<Item = Token>>( partial: bool, ctx: ParseCtx<'_>, token_stream: I, ) -> Result<Self, ()>
Parse an AST node with a shared parsing context. Errors are emitted into
ctx. Read moreSourcefn parse_with_ctx<I: IntoIterator<Item = Token>>(
ctx: ParseCtx<'_>,
token_stream: I,
) -> Result<Self, ()>
fn parse_with_ctx<I: IntoIterator<Item = Token>>( ctx: ParseCtx<'_>, token_stream: I, ) -> Result<Self, ()>
Parse an AST node with a shared parsing context. Errors are emitted into
ctx. Read moreSourcefn partial_parse_with_interner(
partial: bool,
source: &str,
span_base: u32,
interner: &mut Interner,
) -> Result<Self, Vec<Error>>
fn partial_parse_with_interner( partial: bool, source: &str, span_base: u32, interner: &mut Interner, ) -> Result<Self, Vec<Error>>
Convenience method for parsing source without a shared context. Errors are returned
in the
Err variant. Read moreSourcefn parse_with_interner(
source: &str,
span_base: u32,
interner: &mut Interner,
) -> Result<Self, Vec<Error>>
fn parse_with_interner( source: &str, span_base: u32, interner: &mut Interner, ) -> Result<Self, Vec<Error>>
Convenience method for parsing source without a shared context. Errors are returned
in the
Err variant. Read moreimpl Eq for Lit
impl StructuralPartialEq for Lit