pub struct ShortcutOption {
pub span: Span,
pub text: StrBody,
}Fields
span: Spantext: StrBodyTrait Implementations
Sourceimpl Clone for ShortcutOption
impl Clone for ShortcutOption
Sourcefn clone(&self) -> ShortcutOption
fn clone(&self) -> ShortcutOption
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShortcutOption
impl Debug for ShortcutOption
Sourceimpl Parse for ShortcutOption
impl Parse for ShortcutOption
Sourcefn partial_parse_with_ctx<I: IntoIterator<Item = Token>>(
partial: bool,
ctx: ParseCtx<'_>,
token_stream: I,
) -> Result<Self, ()>
fn partial_parse_with_ctx<I: IntoIterator<Item = Token>>( partial: bool, ctx: ParseCtx<'_>, token_stream: I, ) -> Result<Self, ()>
Parse an AST node with a shared parsing context. Errors are emitted into
ctx. Read moreSourcefn parse_with_ctx<I: IntoIterator<Item = Token>>(
ctx: ParseCtx<'_>,
token_stream: I,
) -> Result<Self, ()>
fn parse_with_ctx<I: IntoIterator<Item = Token>>( ctx: ParseCtx<'_>, token_stream: I, ) -> Result<Self, ()>
Parse an AST node with a shared parsing context. Errors are emitted into
ctx. Read moreSourcefn partial_parse_with_interner(
partial: bool,
source: &str,
span_base: u32,
interner: &mut Interner,
) -> Result<Self, Vec<Error>>
fn partial_parse_with_interner( partial: bool, source: &str, span_base: u32, interner: &mut Interner, ) -> Result<Self, Vec<Error>>
Convenience method for parsing source without a shared context. Errors are returned
in the
Err variant. Read moreSourcefn parse_with_interner(
source: &str,
span_base: u32,
interner: &mut Interner,
) -> Result<Self, Vec<Error>>
fn parse_with_interner( source: &str, span_base: u32, interner: &mut Interner, ) -> Result<Self, Vec<Error>>
Convenience method for parsing source without a shared context. Errors are returned
in the
Err variant. Read moreSourceimpl PartialEq for ShortcutOption
impl PartialEq for ShortcutOption
impl Eq for ShortcutOption
impl StructuralPartialEq for ShortcutOption